"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 30.11.20

"""
from django.urls import path

from intervention.autocomplete.intervention import InterventionAutocomplete
from intervention.views.check import check_view
from intervention.views.compensation import remove_compensation_view
from intervention.views.deduction import new_deduction_view, edit_deduction_view, remove_deduction_view
from intervention.views.document import new_document_view, get_document_view, remove_document_view, edit_document_view
from intervention.views.intervention import index_view, new_view, new_id_view, detail_view, edit_view, remove_view
from intervention.views.log import log_view
from intervention.views.record import record_view
from intervention.views.report import report_view
from intervention.views.resubmission import create_resubmission_view
from intervention.views.revocation import new_revocation_view, edit_revocation_view, remove_revocation_view, \
    get_revocation_view
from intervention.views.share import share_view, create_share_view

app_name = "intervention"
urlpatterns = [
    path("", index_view, name="index"),
    path('new/', new_view, name='new'),
    path('new/id', new_id_view, name='new-id'),
    path('<id>', detail_view, name='detail'),
    path('<id>/log', log_view, name='log'),
    path('<id>/edit', edit_view, name='edit'),
    path('<id>/remove', remove_view, name='remove'),
    path('<id>/share/<token>', share_view, name='share'),
    path('<id>/share', create_share_view, name='share-create'),
    path('<id>/check', check_view, name='check'),
    path('<id>/record', record_view, name='record'),
    path('<id>/report', report_view, name='report'),
    path('<id>/resub', create_resubmission_view, name='resubmission-create'),

    # Compensations
    path('<id>/compensation/<comp_id>/remove', remove_compensation_view, name='remove-compensation'),

    # Documents
    path('<id>/document/new/', new_document_view, name='new-doc'),
    path('<id>/document/<doc_id>', get_document_view, name='get-doc'),
    path('<id>/document/<doc_id>/remove/', remove_document_view, name='remove-doc'),
    path('<id>/document/<doc_id>/edit/', edit_document_view, name='edit-doc'),

    # Deductions
    path('<id>/deduction/new', new_deduction_view, name='new-deduction'),
    path('<id>/deduction/<deduction_id>/edit', edit_deduction_view, name='edit-deduction'),
    path('<id>/deduction/<deduction_id>/remove', remove_deduction_view, name='remove-deduction'),

    # Revocation routes
    path('<id>/revocation/new', new_revocation_view, name='new-revocation'),
    path('<id>/revocation/<revocation_id>/edit', edit_revocation_view, name='edit-revocation'),
    path('<id>/revocation/<revocation_id>/remove', remove_revocation_view, name='remove-revocation'),
    path('revocation/<doc_id>', get_revocation_view, name='get-doc-revocation'),

    # Autocomplete
    path("atcmplt/interventions", InterventionAutocomplete.as_view(), name="autocomplete"),
]
